==> REHO-1.0.0.tar.gz: REHO-1.0.0/README.md <==
# REHO
Renewable Energy Hub Optimizer (REHO) is a decision support tool for sustainable urban energy system planning.
REHO simultaneously addresses the optimal design and operation of capacities, catering to multi-objective considerations
across economic, environmental, and efficiency criteria.

Key features:
* MILP Framework
* Multi-Objective Optimization
* Multi-Scale Capabilities
* Multi-Service Consideration
* Multi-Energy Integration
* Open-Source and Open-Data

For more information about the model foundations and features, please refer to the [REHO documentation](https://reho.readthedocs.io/en/main/).

## Authors
REHO is developed by EPFL (Switzerland), within the Industrial Process and Energy Systems Engineering (IPESE) group.

Dorsan Lepour <dorsan.lepour@epfl.ch>  
Cédric Terrier <cedric.terrier@epfl.ch>  
Joseph Loustau <joseph.loustau@epfl.ch>

## Licence
Copyright (C) <2021-2024> <Ecole Polytechnique Fédérale de Lausanne (EPFL), Switzerland>

Licensed under the Apache License, Version0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Description and complete License: see LICENSE file.

## Installation
1. Clone repository available at https://github.com/Renewable-Energy-Hub-Optimizer/REHO
2. Create `venv` in the repository and install required libraries with
```
pip install -r requirements.txt
```
3. Please refer to "Getting started" section of the documentation for step-by-step guidelines.

## Suggestions and contributions
All suggestions or implementation must be tracked with dedicated issues and reported in the project repository.

==> REHO-1.0.2.tar.gz: REHO-1.0.2/README.md <==
# REHO
Renewable Energy Hub Optimizer (REHO) is a decision support tool for sustainable urban energy system planning.
REHO simultaneously addresses the optimal design and operation of capacities, catering to multi-objective considerations
across economic, environmental, and efficiency criteria.

Key features:
* MILP Framework
* Multi-Objective Optimization
* Multi-Scale Capabilities
* Multi-Service Consideration
* Multi-Energy Integration
* Open-Source and Open-Data

For more information about the model foundations and features, please refer to the [REHO documentation](https://reho.readthedocs.io/en/main/).

## Authors
REHO is developed by EPFL (Switzerland), within the Industrial Process and Energy Systems Engineering (IPESE) group.

Dorsan Lepour <dorsan.lepour@epfl.ch>  
Cédric Terrier <cedric.terrier@epfl.ch>  
Joseph Loustau <joseph.loustau@epfl.ch>

## Licence
Copyright (C) <2021-2024> <Ecole Polytechnique Fédérale de Lausanne (EPFL), Switzerland>

Licensed under the Apache License, Version0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Description and complete License: see LICENSE file.

## Installation
1. Clone repository available at https://github.com/IPESE/REHO
2. Create `venv` in the repository and install required libraries with
```
pip install -r requirements.txt
```
3. Please refer to "User guide" section of the documentation for step-by-step guidelines.

## Suggestions and contributions
All suggestions or implementation must be tracked with dedicated issues and reported in the project repository.
